Package: plumbr
Version: 0.6.10
Title: Mutable and Dynamic Data Models
Author: Michael Lawrence, Hadley Wickham
Depends: R (>= 2.10.0)
Imports: utils, methods, objectSignals (>= 0.10.2)
Suggests: plyr, testthat, MASS
URL: https://github.com/ggobi/plumbr/wiki
Maintainer: Michael Lawrence <michafla@gene.com>
Description: The base R data.frame, like any vector, is
    copied upon modification. This behavior is at odds with
    that of GUIs and interactive graphics. To rectify this,
    plumbr provides a mutable, dynamic tabular data model.
    Models may be chained together to form the complex
    plumbing necessary for sophisticated graphical
    interfaces. Also included is a
    general framework for linking datasets; an typical
    use case would be a linked brush.
License: GPL (>= 2)
Collate: 'accessors.r' 'bindings.r' 'coercion.r' 'constructor.r'
        'dimensions.r' 'events.r' 'linking.r' 'mutalist.R' 'names.r'
        'print.r' 'proxy-filter.r' 'selection.r' 'utils.r' 's4.r'
        'import.r' 'globals.r'
NeedsCompilation: no
Packaged: 2022-05-06 18:12:20 UTC; michafla
Repository: CRAN
Date/Publication: 2022-05-06 18:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 21:13:24 UTC; unix
