export(add_listener)
export(as.mutaframe)
exportClasses(mutaframe)
exportClasses(mutalist)
exportClasses(Selection, ItemSelection, RegionSelection)
export(DataSelection)
export(duplex_data_linker)
export(is.mutaframe)
export(is_paused)
export(ItemSelection)
export(match_any_linker)
exportMethods(as.integer, as.numeric, as.logical, as.factor, as.matrix, which)
export(mutaframe)
export(mutalist)
export(mutalist2env)
export(notify_listeners)
export(pause)
export(RegionSelection)
export(remove_listener)
export(shape_changed)
export(unpause)
import(methods)
importClassesFrom(objectSignals,Signal)
importFrom(objectSignals,declareSignal)
importFrom(objectSignals,Signal)
importFrom(utils,head)
importFrom(utils,tail)
S3method(as.data.frame,mutaframe)
S3method(as.data.frame,mutalist)
S3method(as.list,mutaframe)
S3method(as.list,mutalist)
S3method(as.mutaframe,data.frame)
S3method(as.mutaframe,default)
S3method(as.mutaframe,mutaframe)
S3method(c,mutalist)
S3method(dim,mutaframe)
S3method("dimnames<-",mutaframe)
S3method(dimnames,mutaframe)
S3method(head,mutaframe)
S3method(head,mutalist)
S3method(lapply,mutalist)
S3method(length,mutalist)
S3method("[<-",mutaframe)
S3method("[",mutaframe)
S3method("[[<-",mutaframe)
S3method("[[",mutaframe)
S3method("$<-",mutaframe)
S3method("$",mutaframe)
S3method("[<-",mutalist)
S3method("[",mutalist)
S3method("[[<-",mutalist)
S3method("[[",mutalist)
S3method("$<-",mutalist)
S3method("names<-",mutaframe)
S3method(names,mutaframe)
S3method("names<-",mutalist)
S3method(names,mutalist)
S3method(ncol,mutaframe)
S3method(nrow,mutaframe)
S3method(print,mutaframe)
S3method(print,mutalist)
S3method(rep,mutalist)
S3method(rev,mutalist)
S3method(tail,mutaframe)
S3method(tail,mutalist)
S3method(unlist,mutalist)
